==> jena-4.3.1-source-release.zip: jena-4.3.1/jena-arq/src/test/java/org/apache/jena/rdfs/TestStreamRDFS_MaterializedSplit.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.jena.rdfs;

import org.apache.jena.graph.Graph;
import org.apache.jena.riot.system.StreamRDF;
import org.apache.jena.riot.system.StreamRDFLib;
import org.apache.jena.riot.system.StreamRDFOps;
import org.apache.jena.sparql.graph.GraphFactory;
import org.junit.BeforeClass;

/**
 * Test of RDFS.
 * Expanded graph (by stream), split vocab and data.
 */
public class TestStreamRDFS_MaterializedSplit extends AbstractTestGraphRDFS {

    private static Graph testGraphMaterialized;
    @BeforeClass public static void setupHere() {
        testGraphMaterialized = GraphFactory.createDefaultGraph();
        SetupRDFS setup = RDFSFactory.setupRDFS(vocab);
        StreamRDF stream = StreamRDFLib.graph(testGraphMaterialized);
        stream = RDFSFactory.streamRDFS(stream, setup);
        StreamRDFOps.graphToStream(data, stream);
    }

    public TestStreamRDFS_MaterializedSplit() {}

    @Override
    protected boolean removeVocabFromReferenceResults() { return true; }

    @Override
    protected Graph getTestGraph() {
        return testGraphMaterialized;
    }

    @Override
    protected String getTestLabel() {
        return "Expanded, split";
    }
}

==> jena-5.6.0-source-release.zip: jena-5.6.0/jena-arq/src/test/java/org/apache/jena/rdfs/TestStreamRDFS_MaterializedSplit.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.jena.rdfs;

import org.junit.jupiter.api.BeforeAll;

import org.apache.jena.graph.Graph;
import org.apache.jena.riot.system.StreamRDF;
import org.apache.jena.riot.system.StreamRDFLib;
import org.apache.jena.riot.system.StreamRDFOps;
import org.apache.jena.sparql.graph.GraphFactory;

/**
 * Test of RDFS.
 * Expanded graph (by stream), split vocab and data.
 * Materialized version of normal use.
 */
public class TestStreamRDFS_MaterializedSplit extends AbstractTestGraphRDFS {

    private static Graph testGraphMaterialized;

    @BeforeAll public static void setupHere() {
        testGraphMaterialized = GraphFactory.createDefaultGraph();
        SetupRDFS setup = RDFSFactory.setupRDFS(vocab);
        StreamRDF stream = StreamRDFLib.graph(testGraphMaterialized);
        stream = RDFSFactory.streamRDFS(stream, setup);
        StreamRDFOps.graphToStream(data, stream);
    }

    public TestStreamRDFS_MaterializedSplit() {}

    @Override
    protected boolean removeVocabFromReferenceResults() { return true; }

    @Override
    protected Graph getTestGraph() {
        return testGraphMaterialized;
    }

    @Override
    protected String getTestLabel() {
        return "Expanded, split";
    }
}
